==> haskell-persistent-template-2.6.0-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-template
version: 2.6.0
id: persistent-template-2.6.0-DetyhjEITqT1LPkSAnqbfK
key: persistent-template-2.6.0-DetyhjEITqT1LPkSAnqbfK
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.
category: Database, Yesod
abi: 6f5fa923e68063911c7d55e2f1fb5ec6
exposed: True
exposed-modules:
    Database.Persist.TH
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-template-2.6.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-template-2.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-template-2.6.0
hs-libraries: HSpersistent-template-2.6.0-DetyhjEITqT1LPkSAnqbfK
depends:
    aeson-1.4.2.0-7ArGF1xZrLvnrB0s88SSU
    aeson-compat-0.3.9-Ihitz2OJ88q7KeZVW5WMUD base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 ghc-prim-0.5.3
    http-api-data-0.4-JjitiXHGjAXCjV9615MAUx
    monad-control-1.0.2.3-1X2URhF8HacCf5Ysp3ecBG
    monad-logger-0.3.30-925Jm0DLIIrLZBfvMH3OJJ
    path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    persistent-2.9.2-J1qIxpKbRghEhdgbBwtCoy
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP template-haskell-2.14.0.0
    text-1.2.3.1 transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
haddock-interfaces: /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock
haddock-html: /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-template-2.6.0-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-template
version: 2.6.0
id: persistent-template-2.6.0-E2sc0AiABZtFdZnAKafHVq
key: persistent-template-2.6.0-E2sc0AiABZtFdZnAKafHVq
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.
category: Database, Yesod
abi: 4e069d8bbdd8a2ff951f8c7d8b9b59dd
exposed: True
exposed-modules:
    Database.Persist.TH
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-template-2.6.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-template-2.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-template-2.6.0
hs-libraries: HSpersistent-template-2.6.0-E2sc0AiABZtFdZnAKafHVq
depends:
    aeson-1.4.2.0-4xcoKSM2rCuFeYBdCYWLDU
    aeson-compat-0.3.9-D4lmWztGDSiLoSEHasfQGC base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 ghc-prim-0.5.3
    http-api-data-0.4-JjitiXHGjAXCjV9615MAUx
    monad-control-1.0.2.3-1X2URhF8HacCf5Ysp3ecBG
    monad-logger-0.3.30-925Jm0DLIIrLZBfvMH3OJJ
    path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    persistent-2.9.2-7suS0zA4JVzIlqLifa5DE3
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP template-haskell-2.14.0.0
    text-1.2.3.1 transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
haddock-interfaces: /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock
haddock-html: /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
